@@ -238,7 +238,9 @@ class AppSettings(object):
 
     @property
     def LOGOUT_REDIRECT_URL(self):
-        return self._setting("LOGOUT_REDIRECT_URL", "/")
+        from django.conf import settings
+
+        return self._setting("LOGOUT_REDIRECT_URL", settings.LOGOUT_REDIRECT_URL or "/")
 
     @property
     def LOGOUT_ON_GET(self):
